<?php
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	http_response_code(301);
	header('Location: ./' . $_POST['q']);
	die;
}

require_once __DIR__ . '/../include/utils.php';
require_once __DIR__ . '/../include/artworks_grid.php';
require_once __DIR__ . '/../include/paginator.php';

$query = $_GET['q'];

$current_page = (isset($_GET['p']) && ctype_digit($_GET['p']) && $_GET['p'] > 0) ? $_GET['p'] : 1;

list($result, $error) = get_search($query, $current_page);
if ($error) {
	die_with_message(500, get_string($error));
}
$result = $result->body->illustManga;

/* the endpoint always returns 60 per page*/
$per_page = 60;
$page_count = ceil($result->total / $per_page);

render_page_header($query);
?>

<div class="container"><?php
	list($info, $error) = get_tag_info($query);
	if ($error) { ?>
		<div class="tag-bar">
			<h1><?= htmlspecialchars($query) ?></h1>
		</div><?php
	}
	else {
		$info = $info->body ?>
		<div class="tag-bar img-with-text"><?php
			if (isset($info->pixpedia->image)) { ?>
				<img loading="lazy" class="tag-icon" alt=" "
					src="<?= get_proxy_url($info->pixpedia->image) ?>"><?php
			} ?>
			<div><?php
				$tag_translated = '';
				if (isset($info->tagTranslation->{$info->tag})) {
					$tag_translations = $info->tagTranslation->{$info->tag};
					if (!empty($tag_translations->{get_string('pixiv-lang')}))
						$tag_translated = $tag_translations->{get_string('pixiv-lang')};
					else if (!empty($tag_translations->romaji))
						$tag_translated = $tag_translations->romaji;
				} ?>
				<h1><?= htmlspecialchars($info->tag) ?></h1>
				<p><?= htmlspecialchars($tag_translated) ?></p>
			</div>
		</div><?php

		if (isset($info->pixpedia->abstract)) { ?>
			<p><?= htmlspecialchars($info->pixpedia->abstract); ?></p><?php
		}
	} ?>

	<hr>

	<h2 id="artworks"><?= sprintf(get_string('search.work-count'), $result->total) ?></h2>

	<?php
	render_artworks_grid($result->data, true);

	render_paginator($page_count, $current_page, function($page) use ($query) {
		$query = urlencode($query);
		return BASE_URL . "/tags/$query?p=$page#artworks";
	}); ?>
</div>

<?php
render_page_footer();
